@@ -15,6 +15,7 @@ module Fog
         #
         def get_blob_http_url(container_name, blob_name, expires)
           relative_path = "#{container_name}/#{blob_name}"
+          relative_path = remove_trailing_periods_from_path_segments(relative_path)
           params = {
             service: 'b',
             resource: 'b',
@@ -22,7 +23,7 @@ module Fog
             expiry: expires.utc.iso8601
           }
           token = @signature_client.generate_service_sas_token(relative_path, params)
-          uri = @blob_client.generate_uri(relative_path)
+          uri = @blob_client.generate_uri(relative_path, {}, { encode: true })
           url = "#{uri}?#{token}"
           url.gsub('https:', 'http:')
         end
