@@ -15,6 +15,7 @@ module Fog
         #
         def get_blob_https_url(container_name, blob_name, expires)
           relative_path = "#{container_name}/#{blob_name}"
+          relative_path = remove_trailing_periods_from_path_segments(relative_path)
           params = {
             service: 'b',
             resource: 'b',
@@ -23,7 +24,7 @@ module Fog
             protocol: 'https'
           }
           token = @signature_client.generate_service_sas_token(relative_path, params)
-          uri = @blob_client.generate_uri(relative_path)
+          uri = @blob_client.generate_uri(relative_path, {}, { encode: true })
           "#{uri}?#{token}"
         end
       end
